| boot_design | R Documentation |
Explore multiple designs
boot_design( designs, sample = 10000, ..., BPPARAM = BiocParallel::SerialParam() )
designs |
A list of designs such as that obtained with |
sample |
A numeric value with the number of samples to test. |
... |
Arguments passed on to
|
BPPARAM |
Set up parallel backend (see BiocParallel documentation). |
A data.frame with information about the models performance.
boot_index()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.