| iterate_model | R Documentation |
Look for every variation of the models changing the weights by 0.1.
iterate_model(..., BPPARAM = BiocParallel::SerialParam()) search_model(..., nWeights = 3, BPPARAM = BiocParallel::SerialParam())
... |
All the same arguments that would be passed to sggca, pass named arguments. |
BPPARAM |
Set up parallel backend (see BiocParallel documentation). |
nWeights |
The number of weights used to check the possible designs. |
A matrix with the design of the model
search_model: Search for the right model for the blocks provided.
sgcca
data("Russett", package = "RGCCA")
X_agric <- as.matrix(Russett[, c("gini", "farm", "rent")])
X_ind <- as.matrix(Russett[, c("gnpr", "labo")])
X_polit <- as.matrix(Russett[ , c("inst", "ecks", "death", "demostab",
"dictator")])
A <- list(Agric = X_agric, Ind = X_ind, Polit = X_polit)
C <- matrix(c(0, 0, 1, 0, 0, 1, 1, 1, 0), 3, 3)
out <- search_model(A = A, C = C, c1 =rep(1, 3), scheme = "factorial",
scale = FALSE, verbose = FALSE,
ncomp = rep(1, length(A)),
bias = TRUE, BPPARAM = BiocParallel::SerialParam())
head(out)
# From all the models, we select that with the higher inner AVE:
model <- extract_model(C, out, "inner")
# We then look for a variation of the weights of this model
out <- iterate_model(A = A, C = model, c1 =rep(1, 3), scheme = "factorial",
scale = FALSE, verbose = FALSE,
ncomp = rep(1, length(A)),
bias = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.