subsetData: Subset a list

View source: R/subsetData.R

subsetDataR Documentation

Subset a list

Description

Given a list and an index subset each element of the list and remove the variables that are constant.

Usage

subsetData(A, index)

Arguments

A

A list of an array with samples in rows and variables in the columns.

index

The samples to keep.

Value

A list with the samples.

Note

It also removes constant variables of the data.

Examples

data(ge_cgh_locIGR)
A <- subsetData(ge_cgh_locIGR$multiblocks, sample(53, replace = TRUE))
str(A)

llrs/inteRmodel documentation built on April 1, 2022, 4:04 p.m.