| subsetData | R Documentation |
Given a list and an index subset each element of the list and remove the variables that are constant.
subsetData(A, index)
A |
A list of an array with samples in rows and variables in the columns. |
index |
The samples to keep. |
A list with the samples.
It also removes constant variables of the data.
data(ge_cgh_locIGR) A <- subsetData(ge_cgh_locIGR$multiblocks, sample(53, replace = TRUE)) str(A)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.